@@ -1,10 +1,14 @@
 import re
 
-from nonebot import on_regex
+from nonebot import get_driver, on_regex
 from nonebot.adapters.cqhttp import Bot, MessageEvent, MessageSegment
+from nonebot.log import logger
 
+from .weather_data import Weather
 from .render_pic import render
-from .get_weather import *
+
+api_key = get_driver().config.qweather_apikey
+api_type = get_driver().config.qweather_apitype
 
 weather = on_regex(r".*?(.*)天气.*?", priority=1)
 
@@ -24,18 +28,22 @@ async def _(bot: Bot, event: MessageEvent):
     city = get_msg(event.get_plaintext())
     if city is None:
         await weather.finish("地点是...空气吗?? >_<")
-    data = await get_City_Weather(city)
-    if type(data) is int:
-        if data == 404:
-            await weather.finish()
-        else:
-            await weather.finish(f"出错了! 错误代码={data}")
-    img = await render(data) if data else None
 
-    # from PIL import Image
-    # import io
+    w_data = Weather(city_name=city, api_key=api_key, api_type=api_type)
+    await w_data.load_data()
 
-    # a = Image.open(io.BytesIO(img))
-    # a.save("template2pic.png", format="PNG")
+    img = await render(w_data)
+
+    if get_driver().config.debug:
+        debug_save_img(img)
 
     await weather.finish(MessageSegment.image(img))
+
+
+def debug_save_img(img: bytes) -> None:
+    from io import BytesIO
+    from PIL import Image
+
+    logger.debug("将会保存图片到 weather.png")
+    a = Image.open(BytesIO(img))
+    a.save("weather.png", format="PNG")
