@@ -1,20 +1,22 @@
 from pathlib import Path
-
+from .weather_data import Weather
 from nonebot.plugin import require
 
 template_to_pic = require("nonebot_plugin_htmlrender").template_to_pic
 
-async def render(data) -> bytes:
+
+async def render(weather: Weather) -> bytes:
     template_path = str(Path(__file__).parent / "templates")
-    data = add_week(data)
+
     return await template_to_pic(
         template_path=template_path,
         template_name="weather.html",
         templates={
-            "now": convert_now(data),
-            "days": convert_days(data),
-            "city": convert_city(data),
-            "warning": convert_warning(data),
+            "now": weather.now["now"],
+            "days": add_date(weather.daily["daily"]),
+            "city": weather.city_name,
+            "warning": weather.warning,
+            "air": add_tag_color(weather.air["now"]),
         },
         pages={
             "viewport": {"width": 1000, "height": 300},
@@ -22,15 +24,8 @@ async def render(data) -> bytes:
         },
     )
 
-def convert_days(data):
-    days = []
-    for day in range(1, 8):
-        days.append(data[f"day{str(day)}"])
 
-    return days
-
-
-def add_week(data):
+def add_date(daily):
     from datetime import datetime
 
     week_map = [
@@ -42,24 +37,27 @@ def add_week(data):
         "周五",
         "周六",
     ]
-    for day in range(1, 8):
-        date = data[f"day{str(day)}"]["fxDate"].split("-")
+
+    for day in range(len(daily)):
+        date = daily[day]["fxDate"].split("-")
         _year = int(date[0])
         _month = int(date[1])
         _day = int(date[2])
         week = int(datetime(_year, _month, _day, 0, 0).strftime("%w"))
-        data[f"day{str(day)}"]["week"] = week_map[week] if day != 1 else "今日"
-        data[f"day{str(day)}"]["date"] = f"{_month}月{_day}日"
-    return data
+        daily[day]["week"] = week_map[week] if day != 0 else "今日"
+        daily[day]["date"] = f"{_month}月{_day}日"
+
+    return daily
 
 
-def convert_now(data):
-    return data["now"]
-
-
-def convert_warning(data):
-    return data["warning"]
-
-
-def convert_city(data):
-    return data["city"]
+def add_tag_color(air):
+    color = {
+        "优": "#95B359",
+        "良": "#A9A538",
+        "轻度污染": "#E0991D",
+        "中度污染": "#D96161",
+        "重度污染": "#A257D0",
+        "严重污染": "#D94371",
+    }
+    air["tag_color"] = color[air["category"]]
+    return air
